//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[hasYakuman](has-yakuman.md)

# hasYakuman

[common]\

@EncodeDefault

val [hasYakuman](has-yakuman.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否含役满役种
